@@ -136,11 +136,11 @@ check_homogeneity.afex_aov <- function(x, method = "levene", ...) {
   insight::check_if_installed("car")
 
   if (tolower(method) != "levene") {
-    message("Only Levene's test for homogeneity supported for afex_aov")
+    insight::format_alert("Only Levene's test for homogeneity supported for `afex_aov()`.")
   }
 
   if (length(attr(x, "between")) == 0) {
-    stop("Levene test is only aplicable to ANOVAs with between-subjects factors.", call. = FALSE)
+    insight::format_error("Levene test is only aplicable to ANOVAs with between-subjects factors.")
   }
 
   data <- x$data$long # Use this to also get id column
@@ -153,7 +153,9 @@ check_homogeneity.afex_aov <- function(x, method = "levene", ...) {
   colnames(ag_data)[length(c(between, id)) + 1] <- dv
 
   if (any(is_covar)) {
-    warning(insight::format_message("Levene's test is not appropriate with quantitative explanatory variables. Testing assumption of homogeneity among factor groups only."), call. = FALSE)
+    insight::format_warning(
+      "Levene's test is not appropriate with quantitative explanatory variables. Testing assumption of homogeneity among factor groups only."
+    )
     # ## TODO maybe add as option?
     # warning("Testing assumption of homogeneity on residualzied data among factor groups only.", call. = FALSE)
     # ag_data[dv] <- stats::residuals(stats::lm(ag_data[,dv] ~ as.matrix(ag_data[between[is_covar]])))
