@@ -30,6 +30,9 @@ performance_logloss <- function(model, verbose = TRUE, ...) {
 
 #' @export
 performance_logloss.default <- function(model, verbose = TRUE, ...) {
+  # check for valid input
+  .is_model_valid(model)
+
   resp <- .recode_to_zero(insight::get_response(model, verbose = verbose))
   ll <- suppressWarnings(mean(log(1 - abs(resp - stats::fitted(model))) * -1))
 
