@@ -115,7 +115,7 @@ performance_score <- function(model, verbose = TRUE, ...) {
   resp <- if (minfo$is_binomial) {
     .recode_to_zero(resp)
   } else {
-    datawizard::data_to_numeric(resp, dummy_factors = FALSE, preserve_levels = TRUE)
+    datawizard::to_numeric(resp, dummy_factors = FALSE, preserve_levels = TRUE)
   }
   p_y <- prob_fun(resp, mean = pr$pred, pis = pr$pred_zi, sum(resp))
 
