@@ -160,11 +160,14 @@ r2.systemfit <- function(model, ...) {
 r2.lm_robust <- function(model, ...) {
   out <- list(
     "R2" = tryCatch(
-            model[["r.squared"]],
-            error = function(e) NULL),
+      model[["r.squared"]],
+      error = function(e) NULL
+    ),
     "R2_adjusted" = tryCatch(
-            model[["adj.r.squared"]],
-            error = function(e) NULL))
+      model[["adj.r.squared"]],
+      error = function(e) NULL
+    )
+  )
   names(out$R2) <- "R2"
   names(out$R2_adjusted) <- "adjusted R2"
   attr(out, "model_type") <- "Linear"
