@@ -89,8 +89,20 @@ r2_bayes <- function(model, robust = TRUE, ci = .95, verbose = TRUE, ...) {
   if (insight::is_multivariate(model)) {
     structure(
       class = "r2_bayes_mv",
-      rapply(r2_bayesian, ifelse(robust, stats::median, mean)),
-      "SE" = rapply(r2_bayesian, ifelse(robust, stats::mad, stats::sd)),
+      rapply(r2_bayesian, function(i) {
+        if (robust) {
+          stats::median(i)
+        } else {
+          mean(i)
+        }
+      }),
+      "SE" = rapply(r2_bayesian, function(i) {
+        if (robust) {
+          stats::mad(i)
+        } else {
+          stats::sd(i)
+        }
+      }),
       # "Estimates" = rapply(r2_bayesian, bayestestR::point_estimate, centrality = "all", dispersion = TRUE),
       "CI" = rapply(r2_bayesian, bayestestR::hdi, ci = ci),
       "ci_method" = "HDI",
@@ -99,8 +111,20 @@ r2_bayes <- function(model, robust = TRUE, ci = .95, verbose = TRUE, ...) {
   } else {
     structure(
       class = "r2_bayes",
-      lapply(r2_bayesian, ifelse(robust, stats::median, mean)),
-      "SE" = lapply(r2_bayesian, ifelse(robust, stats::mad, stats::sd)),
+      lapply(r2_bayesian, function(i) {
+        if (robust) {
+          stats::median(i)
+        } else {
+          mean(i)
+        }
+      }),
+      "SE" = lapply(r2_bayesian, function(i) {
+        if (robust) {
+          stats::mad(i)
+        } else {
+          stats::sd(i)
+        }
+      }),
       # "Estimates" = lapply(r2_bayesian, bayestestR::point_estimate, centrality = "all", dispersion = TRUE),
       "CI" = lapply(r2_bayesian, bayestestR::hdi, ci = ci),
       "ci_method" = "HDI",
@@ -122,7 +146,9 @@ r2_posterior.brmsfit <- function(model, verbose = TRUE, ...) {
 
   algorithm <- insight::find_algorithm(model)
   if (algorithm$algorithm != "sampling") {
-    warning(insight::format_message("`r2()` only available for models fit using the 'sampling' algorithm."), call. = FALSE)
+    warning(insight::format_message(
+      "`r2()` only available for models fit using the 'sampling' algorithm."
+    ), call. = FALSE)
     return(NA)
   }
 
@@ -147,7 +173,7 @@ r2_posterior.brmsfit <- function(model, verbose = TRUE, ...) {
               summary = FALSE
             )
           )
-          br2 <- lapply(1:length(res), function(x) {
+          br2 <- lapply(seq_along(res), function(x) {
             list(
               "R2_Bayes" = unname(as.vector(br2_mv$R2_Bayes[, x])),
               "R2_Bayes_marginal" = unname(as.vector(br2_mv$R2_Bayes_marginal[, x]))
@@ -156,7 +182,7 @@ r2_posterior.brmsfit <- function(model, verbose = TRUE, ...) {
           names(br2) <- res
         } else {
           br2_mv <- list("R2_Bayes" = rstantools::bayes_R2(model, summary = FALSE))
-          br2 <- lapply(1:length(res), function(x) {
+          br2 <- lapply(seq_along(res), function(x) {
             list("R2_Bayes" = unname(as.vector(br2_mv$R2_Bayes[, x])))
           })
           names(br2) <- res
@@ -267,7 +293,9 @@ r2_posterior.BFBayesFactor <- function(model,
 
   if (any(is.na(BFMods$BF) | is.infinite(BFMods$BF))) {
     if (verbose) {
-      warning(insight::format_message("Can't compute model-averaged index. One or more Bayes factors are NA or infinite."), call. = FALSE)
+      warning(insight::format_message(
+        "Can't compute model-averaged index. One or more Bayes factors are NA or infinite."
+      ), call. = FALSE)
     }
     return(NULL)
   }
