@@ -8,16 +8,16 @@ if (requiet("testthat") && requiet("performance") && requiet("glmmTMB")) {
 
   test_that("check_collinearity", {
     expect_equal(
-      check_collinearity(m1, component = "conditional")$VIF,
+      suppressWarnings(check_collinearity(m1, component = "conditional", verbose = FALSE)$VIF),
       c(1.00037354840318, 1.00037354840318),
       tolerance = 1e-3
     )
     expect_equal(
-      check_collinearity(m1, component = "all")$VIF,
+      suppressWarnings(check_collinearity(m1, component = "all", verbose = FALSE)$VIF),
       c(1.00037354840318, 1.00037354840318),
       tolerance = 1e-3
     )
-    expect_null(check_collinearity(m1, component = "zero_inflated", verbose = FALSE))
+    expect_null(suppressWarnings(check_collinearity(m1, component = "zero_inflated")))
   })
 
   m2 <- glmmTMB(
@@ -29,37 +29,37 @@ if (requiet("testthat") && requiet("performance") && requiet("glmmTMB")) {
 
   test_that("check_collinearity", {
     expect_equal(
-      check_collinearity(m2, component = "conditional")$VIF,
+      suppressWarnings(check_collinearity(m2, component = "conditional", verbose = FALSE)$VIF),
       c(1.09015, 1.2343, 1.17832),
       tolerance = 1e-3
     )
     expect_equal(
-      check_collinearity(m2, component = "conditional")$VIF_CI_low,
+      suppressWarnings(check_collinearity(m2, component = "conditional", verbose = FALSE)$VIF_CI_low),
       c(1.03392, 1.14674, 1.10105),
       tolerance = 1e-3
     )
     expect_equal(
-      check_collinearity(m2, component = "all")$VIF,
+      suppressWarnings(check_collinearity(m2, component = "all", verbose = FALSE)$VIF),
       c(1.09015, 1.2343, 1.17832, 1.26914, 1, 1.26914),
       tolerance = 1e-3
     )
     expect_equal(
-      check_collinearity(m2, component = "all")$VIF_CI_low,
+      suppressWarnings(check_collinearity(m2, component = "all", verbose = FALSE)$VIF_CI_low),
       c(1.03392, 1.14674, 1.10105, 1.17565, 1, 1.17565),
       tolerance = 1e-3
     )
     expect_equal(
-      check_collinearity(m2, component = "zero_inflated")$VIF,
+      suppressWarnings(check_collinearity(m2, component = "zero_inflated", verbose = FALSE)$VIF),
       c(1.26914, 1, 1.26914),
       tolerance = 1e-3
     )
     expect_equal(
-      check_collinearity(m2, component = "zero_inflated")$Tolerance_CI_high,
+      suppressWarnings(check_collinearity(m2, component = "zero_inflated", verbose = FALSE)$Tolerance_CI_high),
       c(0.85059, 1, 0.85059),
       tolerance = 1e-3
     )
 
-    coll <- check_collinearity(m2, component = "all")
+    suppressWarnings(coll <- check_collinearity(m2, component = "all", verbose = FALSE))
     expect_true(all(coll$Tolerance < coll$Tolerance_CI_high))
     expect_true(all(coll$VIF > coll$VIF_CI_low))
 
